@@ -1,10 +1,16 @@
 package POD2::ES;
+use v5.10;
+use base 'POD2::Base';
+
 use warnings;
 use strict;
 
-use base 'POD2::Base';
+use open ':locale';
 
-our $VERSION = '5.16.0.02';
+use base qw(Exporter);
+our @EXPORT = qw(print_pod print_pods);
+
+our $VERSION = '5.16.0.03';
 
 sub search_perlfunc_re {
     return 'Lista de funciones de Perl en orden alfabtico';
@@ -28,6 +34,7 @@ sub pod_info {{
     perlhurd          => '5.16.0',
     perlintro         => '5.16.0',
     perlnumber        => '5.16.0',
+    perlootut         => '5.16.0',
     perlopenbsd       => '5.16.0',
     perlpragma        => '5.16.0',
     perlsource        => '5.16.0',
@@ -42,20 +49,40 @@ sub pod_info {{
 
 sub print_pod {
     my $self = shift;
+
     my @args = @_ ? @_ : @ARGV;
 
+    unless (ref $self) {
+        if (defined $self) {
+            if ($self ne __PACKAGE__) {
+                unshift @args, $self;
+                $self = __PACKAGE__;
+            }
+        }
+        else {
+            $self = __PACKAGE__;
+        }
+    }
+
     my $pods = $self->pod_info;
+
     while (@args) {
         (my $pod = lc(shift @args)) =~ s/\.pod$//;
         if ( exists $pods->{$pod} ) {
-            print "\t'$pod' traducido correspondiente a Perl $pods->{$pod}\n";
+            say "\t'$pod' traducido correspondiente a Perl $pods->{$pod}";
         }
         else {
-            print "\t'$pod' todava no existe\n";
+            say "\t'$pod' todava no existe";
         }
     }
 }
 
+sub print_pods {
+    my $self = shift // __PACKAGE__;
+
+    $self->SUPER::print_pods;
+}
+
 1;
 
 __END__
@@ -66,21 +93,26 @@ POD2::ES - Documentacin de Perl en espaol
 
 =head1 SINOPSIS
 
-  %> perldoc POD2::ES::<nombre_de_pod>	
-
-  use POD2::ES;
-  print_pods();
-  print_pod('pod_foo', 'pod_baz', ...); 
+  %> perldoc POD2::ES::<nombre_de_pod>
 
   %> perl -MPOD2::ES -e print_pods
   %> perl -MPOD2::ES -e print_pod <nombre_de_pod1> <nombre_de_pod2> ...
 
+  use POD2::ES;
+  print_pods();
+  print_pod('pod_foo', 'pod_baz');
+
+  use POD2::ES;
+  my $pod2 = POD2::ES->new();
+  $pod2->print_pods();
+  $pod2->print_pod('perlfunc');
+                                                                                          
+
 =head1 DESCRIPCIN
 
-pod2es es el proyecto de traduccin al espaol de la documentacin bsica de
-Perl. Por su dimensin, es un proyecto a largo plazo.
-
-Vea L<http://github.com/zipf/perldoc-es> para obtener ms informacin.
+Este mdulo contiene los documentos revisados hasta la fecha del proyecto de 
+traduccin al espaol de la documentacin bsica de Perl, que se aloja en 
+L<http://github.com/zipf/perldoc-es>. 
 
 Cuando haya instalado el paquete, puede utilizar el siguiente comando para
 consultar la documentacin:
@@ -166,14 +198,6 @@ expresin regular) para omitir la introduccin, a fin de que el archivo de
 revisin funcione con otros idiomas con la opcin C<-L>, hemos utilizado un
 mecanismo sencillo, similar a un complemento.
 
-El paquete de idioma C<POD2::E<lt>idiomaE<gt>> debe exportar
-C<search_perlfunc_re> para devolver una traduccin de la cadena mencionada en
-el prrafo anterior. Esta cadena se usar para omitir la introduccin de
-F<perlfunc.pod>. Si C<POD2::E<lt>idiomaE<gt>-E<gt>search_perlfunc_re> genera un
-error (o no existe), se restablece el comportamiento predeterminado. Este
-mecanismo permite agregar traducciones de C<POD2::*> adicionales sin necesidad
-de aplicar cada vez la revisin de F<Pod/Perldoc.pm>.
-
 =back
 
 
@@ -243,7 +267,7 @@ L<http://github.com/zipf/perldoc-es>.
 
 =head1 VEA TAMBIN
 
-L<POD2::PT_BR>, L<POD2::IT>, L<POD2::FR>, L<POD2::LT>, L<perl>.
+L<POD2::PT_BR>, L<POD2::IT>, L<POD2::FR>, L<POD2::LT>.
 
 
 =head1 DONATIVOS
